@@ -41,9 +41,12 @@ struct pam_ctx_st {
 	int cr_ret;
 	unsigned changing; /* whether we are entering a new password */
 	str_st msg;
+	str_st prompt;
 	unsigned sent_msg;
 	struct pam_response *replies; /* for safety */
 	unsigned state; /* PAM_S_ */
+	unsigned passwd_counter;
+	size_t prev_prompt_hash;
 };
 
 #endif
