@@ -27,13 +27,13 @@
 typedef struct acct_mod_st {
 	unsigned int type; /* ACCT_TYPE_ */
 	unsigned int auth_types; /* or of the AUTH_TYPEs which are compatible with this */
-	void (*global_init)(void *pool, void* additional);
-	void (*global_deinit)(void);
+	void (*vhost_init)(void **vctx, void *pool, void* additional);
+	void (*vhost_deinit)(void *vctx);
 
 	/* The context provided below is of the authentication method */
-	int (*open_session)(unsigned auth_method, const common_acct_info_st *ai, const void *sid, unsigned sid_size); /* optional, may be null */
-	void (*session_stats)(unsigned auth_method, const common_acct_info_st *ai, struct stats_st *stats); /* optional, may be null */
-	void (*close_session)(unsigned auth_method, const common_acct_info_st *ai, struct stats_st *stats, unsigned discon_reason/*REASON_*/); /* optional may be null */
+	int (*open_session)(void *vctx, unsigned auth_method, const common_acct_info_st *ai, const void *sid, unsigned sid_size); /* optional, may be null */
+	void (*session_stats)(void *vctx, unsigned auth_method, const common_acct_info_st *ai, struct stats_st *stats); /* optional, may be null */
+	void (*close_session)(void *vctx, unsigned auth_method, const common_acct_info_st *ai, struct stats_st *stats, unsigned discon_reason/*REASON_*/); /* optional may be null */
 } acct_mod_st;
 
 /* The accounting messages exchanged with the worker thread are shown in ipc.proto.
