@@ -34,9 +34,9 @@ typedef struct passwd_msg_st {
 typedef struct auth_mod_st {
 	unsigned int type;
 	unsigned int allows_retries; /* whether the module allows retries of the same password */
-	void (*global_init)(void *pool, void* additional);
-	void (*global_deinit)(void);
-	int (*auth_init)(void** ctx, void *pool, const common_auth_init_st *);
+	void (*vhost_init)(void **vctx, void *pool, void* additional);
+	void (*vhost_deinit)(void *vctx);
+	int (*auth_init)(void **ctx, void *pool, void *vctx, const common_auth_init_st *);
 	int (*auth_msg)(void* ctx, void *pool, passwd_msg_st *);
 	int (*auth_pass)(void* ctx, const char* pass, unsigned pass_len);
 	int (*auth_group)(void* ctx, const char *suggested, char *groupname, int groupname_size);
