@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015 Nikos Mavrogiannopoulos
+ * Copyright (C) 2013-2018 Nikos Mavrogiannopoulos
  * Copyright (C) 2015 Red Hat
  *
  * This file is part of ocserv.
@@ -123,9 +123,6 @@ int get_cert_der_handler(worker_st * ws, unsigned http_ver)
 static
 int ca_handler(worker_st * ws, unsigned http_ver, unsigned der)
 {
-#if GNUTLS_VERSION_NUMBER < 0x030205
-	return -1;
-#else
 	if (ws->conn_type != SOCK_TYPE_UNIX) { /* we have TLS */
 		const gnutls_datum_t *certs;
 		gnutls_datum_t out = {NULL, 0}, tmpca;
@@ -162,7 +159,7 @@ int ca_handler(worker_st * ws, unsigned http_ver, unsigned der)
 		}
 
 		for (i=0;i<8;i++) {
-			ret = gnutls_certificate_get_crt_raw(ws->creds->xcred, i, 1, &tmpca);
+			ret = gnutls_certificate_get_crt_raw(WSCREDS(ws)->xcred, i, 1, &tmpca);
 			if (ret < 0) {
 				goto cleanup;
 			}
@@ -207,7 +204,6 @@ int ca_handler(worker_st * ws, unsigned http_ver, unsigned der)
 	} else {
 		return -1;
 	}
-#endif
 }
 
 int get_ca_handler(worker_st * ws, unsigned http_ver)
